Crate normalize_interval
source ·Expand description
Provides a basic bounded interval type for doing complex set selections.
Re-exports
Modules
- Provides a bound type for intervals.
- Provides an interval type for doing set selection and iteration.
- Provides an interval type for doing set selection and iteration.
- Non-normalizing interval type.
- Provides a set of possibly noncontiguous intervals.
- Orderable
Tinerepresenting an interval bound. - Interval
TineTreeimplementation.